"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeltaManager = void 0;
const common_utils_1 = require("@fluidframework/common-utils");
const protocol_definitions_1 = require("@fluidframework/protocol-definitions");
const server_services_client_1 = require("@fluidframework/server-services-client");
const server_services_telemetry_1 = require("@fluidframework/server-services-telemetry");
const tenant_1 = require("./tenant");
const server_services_utils_1 = require("@fluidframework/server-services-utils");
/**
 * Manager to fetch deltas from Alfred using the internal URL.
 * @internal
 */
class DeltaManager {
    constructor(authEndpoint, internalAlfredUrl) {
        this.authEndpoint = authEndpoint;
        this.internalAlfredUrl = internalAlfredUrl;
        this.tenantManager = new tenant_1.TenantManager(this.authEndpoint, "");
    }
    async getDeltas(_collectionName, tenantId, documentId, from, to, caller) {
        const baseUrl = `${this.internalAlfredUrl}`;
        const restWrapper = await this.getBasicRestWrapper(tenantId, documentId, baseUrl);
        const resultP = restWrapper.get(`/deltas/${tenantId}/${documentId}`, { from, to, caller: caller ?? "Unknown" });
        return resultP;
    }
    async getDeltasFromStorage(collectionName, tenantId, documentId, fromTerm, toTerm, fromSeq, toSeq) {
        throw new Error("Method not implemented.");
    }
    async getDeltasFromSummaryAndStorage(collectionName, tenantId, documentId, from, to) {
        throw new Error("Method not implemented.");
    }
    async getAccessToken(tenantId, documentId, scopes, includeDisabledTenant = false) {
        const tokenP = await this.tenantManager.signToken(tenantId, documentId, scopes, undefined, undefined, undefined, undefined, includeDisabledTenant);
        return tokenP;
    }
    async getBasicRestWrapper(tenantId, documentId, baseUrl) {
        const scopes = [protocol_definitions_1.ScopeType.DocRead];
        const accessToken = await this.getAccessToken(tenantId, documentId, scopes);
        const defaultQueryString = {
            token: (0, common_utils_1.fromUtf8ToBase64)(`${tenantId}`),
        };
        const getDefaultHeaders = () => {
            const token = { jwt: accessToken };
            return {
                Authorization: `Basic ${token.jwt}`,
            };
        };
        const refreshTokenIfNeeded = (0, tenant_1.getRefreshTokenIfNeededCallback)(this.tenantManager, documentId, tenantId, scopes, "deltaManager");
        const restWrapper = new server_services_client_1.BasicRestWrapper(baseUrl, defaultQueryString, undefined, undefined, getDefaultHeaders(), undefined, undefined, getDefaultHeaders, () => (0, server_services_telemetry_1.getGlobalTelemetryContext)().getProperties().correlationId /* getCorrelationId */, () => (0, server_services_telemetry_1.getGlobalTelemetryContext)().getProperties() /* getTelemetryContextProperties */, refreshTokenIfNeeded, server_services_utils_1.logHttpMetrics);
        return restWrapper;
    }
}
exports.DeltaManager = DeltaManager;
//# sourceMappingURL=deltaManager.js.map